@@ -4,11 +4,11 @@ from urllib.parse import urljoin
 import requests as requests
 from dotenv import load_dotenv
 
-from cloudtipsadp.configuration import Token
+from cloudtipsadp.config import Token
 from cloudtipsadp.constants import (API_VERSION, BASE_URL, BASE_URL_API,
-                                        BASE_URL_API_SANDBOX, BASE_URL_SANDBOX,
-                                        HEADERS_REQUEST, M_BAD_CONNECT,
-                                        M_BASE_IMPLEMENTED)
+                                    BASE_URL_API_SANDBOX, BASE_URL_SANDBOX,
+                                    HEADERS_REQUEST, M_BAD_CONNECT,
+                                    M_BASE_IMPLEMENTED)
 
 load_dotenv()
 
