@@ -1,9 +1,8 @@
 import json
-import os
 
 import requests as requests
 
-from cloudtipsadp import Places
+from cloudtipsadp.places import Places
 from cloudtipsadp.clients import Connect, SandboxClient
 from cloudtipsadp.constants import M_BASE_IMPLEMENTED
 
@@ -46,13 +45,9 @@ class Receivers(Receiver):
         return response.json()
 
 
-def receiver_create(receiver: Receiver):
-    return receiver.create()
-
-
 if __name__ == '__main__':
     connect = Connect(SandboxClient())
     # connect.get_token()
-    ob = receiver_create(Receivers('Adam', '+79162047558'))
-    if ob.get('succeed'):
-        print(f'Получатель создан. {ob}')
+    # ob = receiver_create(Receivers('Adam', '+79162047558'))
+    # if ob.get('succeed'):
+    #     print(f'Получатель создан. {ob}')
